@@ -33,7 +33,11 @@ class SummernoteWidget(Textarea):
 
     def __init__(self, attrs=None, editor_options=None):
         super().__init__(attrs)
-        self.editor_options = editor_options or get_setting("WYSIWYG_CONFIG") or get_setting("SUMMERNOTE_CONFIG") 
+        self.editor_options = (
+            editor_options
+            or get_setting("WYSIWYG_CONFIG")
+            or get_setting("SUMMERNOTE_CONFIG")
+        )
 
     def render(self, name, value, attrs=None, renderer=None):
         if value is None:
@@ -90,4 +94,6 @@ class RichTextField(models.TextField):
         return super().formfield(**defaults)
 
 
-options.FORMFIELD_FOR_DBFIELD_DEFAULTS[RichTextField] = {"widget": get_setting("WYSIWYG_WIDGET") or SummernoteWidget}
+options.FORMFIELD_FOR_DBFIELD_DEFAULTS[RichTextField] = {
+    "widget": get_setting("WYSIWYG_WIDGET") or SummernoteWidget
+}
